/**************************************************************************
***    
*** Copyright (c) 2003 Regents of the University of Michigan,
***               Hayward H. Chan and Igor L. Markov
***
***  Contact author(s): hhchan@umich.edu, imarkov@umich.edu
***  Original Affiliation:   EECS Department, 
***                          The University of Michigan,
***                          Ann Arbor, MI 48109-2122
***
***  Permission is hereby granted, free of charge, to any person obtaining 
***  a copy of this software and associated documentation files (the
***  "Software"), to deal in the Software without restriction, including
***  without limitation 
***  the rights to use, copy, modify, merge, publish, distribute, sublicense, 
***  and/or sell copies of the Software, and to permit persons to whom the 
***  Software is furnished to do so, subject to the following conditions:
***
***  The above copyright notice and this permission notice shall be included
***  in all copies or substantial portions of the Software.
***
*** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
*** EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
*** OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
*** IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
*** CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
*** OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
*** THE USE OR OTHER DEALINGS IN THE SOFTWARE.
***
***
***************************************************************************/
#include <iostream>
#include <fstream>
#include <string>

using namespace std;

int main(int argc, char* argv[])
{
   ifstream infile;
   ofstream outfile;

   if (argc < 3)
   {
      cout << "usage: " << argv[0] << " <infile> <outfile>" << endl;
      exit(1);
   }
   
   infile.open(argv[1]);
   if (!infile.good())
   {
      cout << "Cannot open file: " << argv[1] << endl;
      exit(1);
   }   

   outfile.open(argv[2]);
   if (!outfile.good())
   {
      cout << "Cannot open file: "<< argv[2] << endl;
      exit(1);
   }

   int blockNum = -1;
   double width, height;
   string dummy;
   char semicolon;

   outfile.setf(ios::fixed);
   outfile.precision(2);

   infile.ignore(1000, '\n');
   for (int i = 0; i < 3; i++)
   {
      string leadingWord;
      infile >> leadingWord;
      if (leadingWord == "#")
	 i--;
      else if (leadingWord == "NumHardRectilinearBlocks")
	 infile >> semicolon >> blockNum;
      infile.ignore(1000, '\n');
   }
   outfile << blockNum << endl; 

   for (int k = 0; k < blockNum; k++)
   {
      string name, type;
      int numCorner;
      double value;      
      infile >> name >> type >> numCorner;
      
      char paren, comma;
      infile >> paren >> value >> comma >> value >> paren;
      infile >> paren >> value >> comma >> height >> paren;
      infile >> paren >> width >> comma >> value >> paren;
      outfile << width << " " << height << endl;
      
      infile.ignore(1000, '\n');
      if (!infile.good())
      {
	 cout << "Error in reading block " << k << endl;
	 exit(1);
      }
   }
   infile.close();
   outfile.close();

   return 0;
}
   
